/* 
 * DHCP Web Services MMC 3.0 Snap-In Client
 *
 *  File: DwsSnapIn.cs
 *  Namespace: Unf.Dhcp.ManagementConsole
 *  
 *
 * Copyright (c) 2008 Jason Rupard 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *     * Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 * 
*/
using System;
using System.Collections;
using System.Collections.Generic;
using System.Text;
using System.ComponentModel;
using System.IO;
using System.Drawing;
using System.Runtime.Serialization;
using System.Runtime.Serialization.Formatters.Binary;
using System.Security.Permissions;
using Microsoft.ManagementConsole;

[assembly: PermissionSetAttribute(SecurityAction.RequestMinimum, Unrestricted = true)]

namespace Unf.Dhcp.ManagementConsole
{

    /// <summary>
    /// RunInstaller attribute - Allows the .Net framework InstallUtil.exe to install the assembly.
    /// SnapInInstaller class - Installs snap-in for MMC.
    /// </summary>
    [RunInstaller(true)]
    public class InstallUtilSupport : SnapInInstaller
    {
    }

    /// <summary>
    ///
    /// </summary>
    [SnapInSettings("{E023B15F-BC57-45e4-90CD-371CE15D184A}",
         DisplayName = "DHCP Web Services Console",
         Description = "DHCP Web Services Management Console")]
    public class DwsSnapIn : SnapIn
    {
        /// <summary>
        /// 
        /// </summary>
        public DwsSnapIn()
        {
            SnapInUtil.Init(this);
            //root node

            Color transparentColor = Color.FromArgb(255, 0, 255);

            Bitmap bitmap = new Bitmap(typeof(DwsSnapIn).Assembly.GetManifestResourceStream("Unf.Dhcp.ManagementConsole.SmallIcons.bmp"));
            this.SmallImages.TransparentColor = transparentColor;
            this.SmallImages.AddStrip(bitmap);
            bitmap = new Bitmap(typeof(DwsSnapIn).Assembly.GetManifestResourceStream("Unf.Dhcp.ManagementConsole.LargeIcons.bmp"));
            this.LargeImages.TransparentColor = transparentColor;
            this.LargeImages.AddStrip(bitmap);
            
            this.RootNode = new DwsRootNode();
        }

        protected override void OnLoadCustomData(AsyncStatus status, byte[] persistenceData)
        {
            BinaryFormatter bf = new BinaryFormatter();
            MemoryStream ms = new MemoryStream(persistenceData);
            ProfileSaveData[] profiles = (ProfileSaveData[])bf.Deserialize(ms);
            ms.Close();
            ((DwsRootNode)this.RootNode).GenerateProfileNode(profiles);
        }

        protected override byte[] OnSaveCustomData(SyncStatus status)
        {
            //if (saveData == null)
            //    return base.OnSaveCustomData(status);

            ProfileSaveData[] profiles = new ProfileSaveData[this.RootNode.Children.Count];
            BinaryFormatter bf = new BinaryFormatter();
            MemoryStream ms = new MemoryStream();
            int i = 0;
            foreach (ProfileScopeNode psn in this.RootNode.Children)
            {
                profiles[i++] = psn.SaveData;
            }

            bf.Serialize(ms, profiles);

            return ms.GetBuffer();
        }
    }

}
