/* 
 * DHCP Web Services MMC 3.0 Snap-In Client
 *
 *  File: DnsControl.cs
 *  Namespace: Unf.Dhcp.ManagementConsole
 *  
 *
 * Copyright (c) 2008 Jason Rupard 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *     * Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 * 
*/
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using Microsoft.ManagementConsole;

namespace Unf.Dhcp.ManagementConsole
{
    public partial class DnsControl : UserControl
    {
        private DnsPropertyPage parentPage;

        public DnsControl(DnsPropertyPage parentPage)
        {
            InitializeComponent();
            this.parentPage = parentPage;
        }


        public UInt32 GetData()
        {
            UInt32 value81 = 1;
            if (!cbEnableDDNS.Checked)
                return 0;

            if (cbDDNSnoRequest.Checked)
                value81 += 2;

            if (cbDelete.Checked)
                value81 += 4;

            if (rbDDNSAlways.Checked)
                value81 += 16;

            return value81;
        }

        public void SetData(UInt32 value81)
        {
            if ((value81 & 0x00000001) == 0)
            {
                cbEnableDDNS.Checked = false;
                rbDDNSByRequest.Enabled = false;
                rbDDNSAlways.Enabled = false;
                cbDelete.Enabled = false;
                cbDDNSnoRequest.Enabled = false;
                return;
            }

            cbEnableDDNS.Checked = true;
            if ((value81 & 0x00000002) == 0x00000002)
                cbDDNSnoRequest.Checked = true;

            if ((value81 & 0x00000004) == 0x00000004)
                cbDelete.Checked = true;

            if ((value81 & 0x00000010) == 0x00000010)
                rbDDNSAlways.Checked = true;
            return;
        }

        private void cbEnableDDNS_CheckedChanged(object sender, EventArgs e)
        {
            if (((CheckBox)sender).Checked)
            {
                rbDDNSByRequest.Enabled = true;
                rbDDNSAlways.Enabled = true;
                cbDelete.Enabled = true;
                cbDDNSnoRequest.Enabled = true;
            }
            else
            {
                rbDDNSByRequest.Enabled = false;
                rbDDNSAlways.Enabled = false;
                cbDelete.Enabled = false;
                cbDDNSnoRequest.Enabled = false;
            }

            if (this.parentPage != null)
                this.parentPage.Dirty = true;
        }
    }
}
