/* 
 * DHCP Web Services MMC 3.0 Snap-In Client
 *
 *  File: IprPermissionForm.cs
 *  Namespace: Unf.Dhcp.ManagementConsole
 *  
 *
 * Copyright (c) 2008 Jason Rupard 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *     * Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 * 
*/
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

using Unf.Dhcp.ManagementConsole.DwsSec;

namespace Unf.Dhcp.ManagementConsole
{
    public partial class IprPermissionForm : Form
    {
        private SubnetScopeNode subnetNode;
        public IprPermissionForm(SubnetScopeNode subnetNode)
        {
            this.subnetNode = subnetNode;
            InitializeComponent();

            foreach (Object role in Enum.GetValues(typeof(DhcpAzRole)))
            {
                cbRoles.Items.Add(role);
            }
        }

        private void cbRoles_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (this.tbAccount.Text.Trim().Length != 0)
                this.btnAdd.Enabled = true;
            else
                this.btnAdd.Enabled = false;
        }

        private void tbAccount_TextChanged(object sender, EventArgs e)
        {
            if (this.tbAccount.Text.Trim().Length != 0 && cbRoles.SelectedItem != null)
                this.btnAdd.Enabled = true;
            else
                this.btnAdd.Enabled = false;
        }

        

        private void btnAdd_Click(object sender, EventArgs e)
        {
            if (_AddRangePerm())
            {
                this.DialogResult = DialogResult.OK;
            }
        }

        private Boolean _AddRangePerm()
        {
            if (!MyValidate())
                return false;

            DhcpAzIpRangeScope ipr = new DhcpAzIpRangeScope();
            ipr.ScopeType = DhcpAzScopeType.IpRange;
            ipr.Server = new DhcpIpAddress(subnetNode.ServerIp.ToString());
            ipr.Subnet = new DhcpIpAddress(subnetNode.DhcpSubnet.Address.ToString());
            ipr.StartIp = new DhcpIpAddress(tbStartIp.Text.Trim());
            ipr.EndIp = new DhcpIpAddress(tbEndIp.Text.Trim());
            DhcpAzAccount account = new DhcpAzAccount();
            account.AccountName = tbAccount.Text.Trim();
            account.Role = (DhcpAzRole)cbRoles.SelectedItem;
            try
            {
                subnetNode.ProfileNode.DhcpSec.AddPermission(ipr, account);
            }
            catch
            {
                SnapInUtil.PopUpError("Permission Op Failed",
                                    "Unable to Add Permission: " + Environment.NewLine +
                                    "Does User '" + account.AccountName + "' Exist?");
                return false;
            }
            return true;
        }

        private Boolean MyValidate()
        {
            String caption = "Input Error";

            DhcpIpAddress startIp = null;
            try
            {
                startIp = new DhcpIpAddress(tbStartIp.Text.Trim());
            }
            catch
            {
                MessageBox.Show(this, "Start IP not valid", caption, MessageBoxButtons.OK, MessageBoxIcon.Error);
                return false;
            }

            DhcpIpAddress endIp = null;
            try
            {
                if (tbEndIp.Text.Trim().Length == 0)
                    endIp = startIp;
                else
                    endIp = new DhcpIpAddress(tbEndIp.Text.Trim());
            }
            catch
            {
                MessageBox.Show(this, "End IP not valid", caption, MessageBoxButtons.OK, MessageBoxIcon.Error);
                return false;
            }

            //check mask
            DwsOps.DhcpSubnet network = subnetNode.DhcpSubnet;
            if ((startIp.GetUIntAddress() & network.Mask.GetUIntAddress()) != network.Address.GetUIntAddress()
                || (endIp.GetUIntAddress() & network.Mask.GetUIntAddress()) != network.Address.GetUIntAddress())
            {
                MessageBox.Show(this, "IP Range not within subnet", caption, MessageBoxButtons.OK, MessageBoxIcon.Error);
                return false;
            }

            //check sip < eip
            if (!(startIp.GetUIntAddress() <= endIp.GetUIntAddress()))
            {
                MessageBox.Show(this, "IP Range not correct", caption, MessageBoxButtons.OK, MessageBoxIcon.Error);
                return false;
            }

            return true;
        }
    }
}
