/* 
 * DHCP Web Services MMC 3.0 Snap-In Client
 *
 *  File: SubnetAdvControl.cs
 *  Namespace: Unf.Dhcp.ManagementConsole
 *  
 *
 * Copyright (c) 2008 Jason Rupard 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *     * Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 * 
*/
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;

using Unf.Dhcp.ManagementConsole.DwsOps;

namespace Unf.Dhcp.ManagementConsole
{
    public partial class SubnetAdvControl : UserControl
    {
        private SubnetAdvPropertyPage parentPage;
        public SubnetAdvControl()
        {
            InitializeComponent();
        }

        public SubnetAdvControl(SubnetAdvPropertyPage parentPage)
        {
            InitializeComponent();
            this.parentPage = parentPage;
        }

        public Boolean GetData(out DhcpSubnetElementDataType type, out DhcpOptionValue value51)
        {
            if (rbDhcpOnly.Checked)
                type = DhcpSubnetElementDataType.DhcpIpRangesDhcpOnly;
            else if (rbBootpOnly.Checked)
                type = DhcpSubnetElementDataType.DhcpIpRangesBootpOnly;
            else
                type = DhcpSubnetElementDataType.DhcpIpRangesDhcpBootp;

            TimeSpan ts = new TimeSpan((int)this.nudDays.Value, (int)this.nudHours.Value,
                   (int)this.nudMinutes.Value, 0);

            value51 = new DhcpOptionValue();
            value51.OptionId = 51;
            value51.ClassType = DhcpOptionClassType.Bootp;
            DhcpOptionDataDword od = new DhcpOptionDataDword();
            od.Type = DhcpOptionDataType.DWordType;
            od.Data = new UInt32[] { (UInt32)ts.TotalSeconds };
            value51.OptionData = od;

            DhcpOptionScope os = new DhcpOptionScope();
            os.type = DhcpOptionScopeType.Subnet;
            os.SubnetIp = this.parentPage.subnetNode.DhcpSubnet.Address;
            value51.OptionScope = os;

            return true;
        }

        public void SetData(DhcpSubnetElementDataType type, DhcpOptionValue value51)
        {
            switch (type)
            {
                case DhcpSubnetElementDataType.DhcpIpRangesDhcpOnly:
                    rbDhcpOnly.Checked = true;
                    break;
                case DhcpSubnetElementDataType.DhcpIpRangesBootpOnly:
                    rbBootpOnly.Checked = true;
                    break;
                case DhcpSubnetElementDataType.DhcpIpRangesDhcpBootp:
                    rbBoth.Checked = true;
                    break;
                default:
                    break;
            }

            if (value51 != null)
            {
                TimeSpan ts = TimeSpan.FromSeconds(((DhcpOptionDataDword)value51.OptionData).Data[0]);

                this.nudDays.Value = ts.Days;
                this.nudHours.Value = ts.Hours;
                this.nudMinutes.Value = ts.Minutes;
            }

            if (this.parentPage != null)
            {
                this.parentPage.Dirty = false;
            }
        }

        private void TypeChanged(object sender, EventArgs e)
        {
            //if control is being used by propertey page
            if (this.parentPage != null)
            {
                this.parentPage.Dirty = true;
            }
        }

        private void LeaseTimeChanged(object sender, EventArgs e)
        {
            //if control is being used by propertey page
            if (this.parentPage != null)
            {
                this.parentPage.Dirty = true;
            }
        }
    }
}
