/* 
 * DHCP Web Services MMC 3.0 Snap-In Client
 *
 *  File: DwsRootNode.cs
 *  Namespace: Unf.Dhcp.ManagementConsole
 *  
 *
 * Copyright (c) 2008 Jason Rupard 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *     * Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 * 
*/
using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.ManagementConsole;
using System.Windows.Forms;

namespace Unf.Dhcp.ManagementConsole
{
    public class DwsRootNode : ScopeNode
    {
        public DwsRootNode()
        {
            //node characteristics
            this.DisplayName = "DWS";
            this.ImageIndex = this.SelectedImageIndex = 5;
            //actions
            this.ActionsPaneItems.Add(new SyncAction("Create Profile...", "Creates a Global DWS Profile", 0, "CreateProfile"));
            
        }

        protected override void OnSyncAction(SyncAction action, SyncStatus status)
        {
            switch ((string)action.Tag)
            {
                case "CreateProfile":
                    {
                        ProfileForm createProfile = new ProfileForm();
                        createProfile.Text = "New " + createProfile.Text + "...";

                        if (this.SnapIn.Console.ShowDialog(createProfile) == DialogResult.OK)
                        {
                            this.GenerateProfileNode(createProfile);
                        }
                        break;
                    }
            }
        }

        public void GenerateProfileNode(ProfileForm formData)
        {
            foreach (ProfileScopeNode node in this.Children)
            {
                if (node.DisplayName == formData.pcCreate.GetData().ProfileName)
                {
                    SnapInUtil.PopUpError("Profile Create Failed", "Duplicate Profile Name: " + node.DisplayName);
                    return;
                }
            }

            ProfileScopeNode psn = new ProfileScopeNode(formData.pcCreate.GetData());
            this.Children.Add(psn);
            this.SnapIn.IsModified = true;
        }

        public void GenerateProfileNode(ProfileSaveData[] profiles)
        {
            foreach (ProfileSaveData psd in profiles)
            {
                ProfileScopeNode psn = new ProfileScopeNode(psd);
                this.Children.Add(psn);
            }
        }
    }
}
