/* 
 * DHCP Web Services MMC 3.0 Snap-In Client
 *
 *  File: DnsPropertyPage.cs
 *  Namespace: Unf.Dhcp.ManagementConsole
 *  
 *
 * Copyright (c) 2008 Jason Rupard 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *     * Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 * 
*/
using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.ManagementConsole;

using Unf.Dhcp.ManagementConsole.DwsOps;

namespace Unf.Dhcp.ManagementConsole
{
    public class DnsPropertyPage : PropertyPage
    {
        private ScopeNode parentNode;
        private DhcpIpAddress rezIp;
        public DnsPropertyPage(ServerScopeNode parentNode)
        {
            this.Title = "DNS";

            this.parentNode = parentNode;
            this.rezIp = null;
            //assign control
            this.Control = new DnsControl(this);

        }

        public DnsPropertyPage(SubnetScopeNode parentNode)
        {
            this.Title = "DNS";

            this.parentNode = parentNode;
            this.rezIp = null;

            //assign control
            this.Control = new DnsControl(this);

        }

        public DnsPropertyPage(SubnetScopeNode parentNode, DhcpIpAddress rezIp)
        {
            this.Title = "DNS";

            this.parentNode = parentNode;
            this.rezIp = rezIp;

            //assign control
            this.Control = new DnsControl(this);

        }

        protected override void OnInitialize()
        {
            base.OnInitialize();

            this.GetOption81();

            this.Dirty = false;
        }

        protected override bool OnApply()
        {
            if (this.Dirty)
            {
                this.SetOption81();
            }
            return true;
        }

        protected override bool OnOK()
        {
            return this.OnApply();
        }

        private void GetOption81()
        {
            DhcpOptionScope optScope = new DhcpOptionScope();
            DhcpIpAddress server = null;
            DhcpOperations Ops = null;
            if (this.parentNode.GetType() == typeof(ServerScopeNode))
            {
                ServerScopeNode node = (ServerScopeNode)parentNode;
                optScope.type = DhcpOptionScopeType.Server;
                server = node.ServerIp;
                Ops = node.ProfileNode.DhcpOps;
            }
            else if (this.parentNode.GetType() == typeof(SubnetScopeNode))
            {
                SubnetScopeNode node = (SubnetScopeNode)parentNode;
                server = node.ServerIp;
                optScope.SubnetIp = node.DhcpSubnet.Address;

                if(rezIp == null)
                {
                    optScope.type = DhcpOptionScopeType.Subnet;
                }
                else
                {
                    optScope.type = DhcpOptionScopeType.Reservation;
                    optScope.ReservationIp = rezIp;
                }
               
                Ops = node.ProfileNode.DhcpOps;
            }
            else
                throw new InvalidOperationException("Node Type for DNS Property Page incorrect");

            try
            {
                DhcpOptionValue value = Ops.GetOptionValue(server, 81, DhcpOptionClassType.Dhcp, optScope);
                ((DnsControl)this.Control).SetData(((DhcpOptionDataDword)value.OptionData).Data[0]);
            }
            catch
            {
                ((DnsControl)this.Control).SetData(0);
            }
            return;
            
        }

        private void SetOption81()
        {
            DhcpOptionValue value = new DhcpOptionValue();
            value.ClassType = DhcpOptionClassType.Dhcp;
            value.OptionId = 81;
            value.OptionScope = new DhcpOptionScope();
            DhcpIpAddress server = null;
            DhcpOperations Ops = null;

            DhcpOptionDataDword od = new DhcpOptionDataDword();
            od.Type = DhcpOptionDataType.DWordType;
            od.Data = new UInt32[] { ((DnsControl)this.Control).GetData() };
            value.OptionData = od;

            if (this.parentNode.GetType() == typeof(ServerScopeNode))
            {
                ServerScopeNode node = (ServerScopeNode)parentNode;
                value.OptionScope.type = DhcpOptionScopeType.Server;
                server = node.ServerIp;
                Ops = node.ProfileNode.DhcpOps;
            }
            else if (this.parentNode.GetType() == typeof(SubnetScopeNode) && this.rezIp == null)
            {
                SubnetScopeNode node = (SubnetScopeNode)parentNode;
                server = node.ServerIp;
                value.OptionScope.type = DhcpOptionScopeType.Subnet;
                value.OptionScope.SubnetIp = node.DhcpSubnet.Address;
                Ops = node.ProfileNode.DhcpOps;
            }
            else if (this.parentNode.GetType() == typeof(SubnetScopeNode) && this.rezIp != null)
            {
                SubnetScopeNode node = (SubnetScopeNode)parentNode;
                server = node.ServerIp;
                value.OptionScope.type = DhcpOptionScopeType.Reservation;
                value.OptionScope.SubnetIp = node.DhcpSubnet.Address;
                value.OptionScope.ReservationIp = this.rezIp;
                Ops = node.ProfileNode.DhcpOps;
            }
            else
                throw new InvalidOperationException("Node Type for DNS Property Page incorrect");

            try
            {
                Ops.SetOptionValue(server, value);
            }
            catch (Exception e)
            {
                SnapInUtil.PopUpError("Option Error",
                "Unable to set DHCP Option: " + Environment.NewLine +
                "Error: " + e.Message);
                return;
            }
            return;

        }
    }
}
