/* 
 * DHCP Web Services MMC 3.0 Snap-In Client
 *
 *  File: OptionPropertyPage.cs
 *  Namespace: Unf.Dhcp.ManagementConsole
 *  
 *
 * Copyright (c) 2008 Jason Rupard 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *     * Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 * 
*/
using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.ManagementConsole;

using Unf.Dhcp.ManagementConsole.DwsOps;

namespace Unf.Dhcp.ManagementConsole
{
    public class OptionPropertyPage : PropertyPage
    {
        public OptionScopeNode OptionNode;
        public OptionPropertyPage(OptionScopeNode optionNode)
        {
            //keep track of node data
            this.OptionNode = optionNode;

            if (optionNode.OptScope.type == DhcpOptionScopeType.Reservation)
                this.Title = "Options";
            else
                this.Title = "General";

            //assign control
            this.Control = new OptionControl(this);
        }
        protected override void OnInitialize()
        {
            base.OnInitialize();

            this.SetData();
        }

        protected override bool OnApply()
        {
            if (this.Dirty)
            {
                List<DhcpOptionValue> oldValues =  OptionNode.OptionValues;
                List<DhcpOptionValue> newValues = ((OptionControl)this.Control).GetData();

                foreach (DhcpOptionValue newValue in newValues)
                {
                    if (newValue.OptionId == 81)
                        continue;

                    try
                    {
                        OptionNode.ServerNode.ProfileNode.DhcpOps.SetOptionValue(OptionNode.ServerNode.ServerIp, newValue);
                    }
                    catch (Exception e)
                    {
                        SnapInUtil.PopUpError("Option Error", "Set Option Failed" + Environment.NewLine +
                            "Error: " + e.Message);
                        return false;
                    }
                }

               
                foreach (DhcpOptionValue oldValue in oldValues)
                {
                    if (oldValue.OptionId == 81)
                        continue;

                    Boolean found = false;
                    foreach (DhcpOptionValue newValue in newValues)
                        if (newValue.OptionId == oldValue.OptionId && newValue.ClassType == oldValue.ClassType)
                        {
                            found = true;
                            break;
                        }
                    if (!found)
                    {
                        try
                        {
                            OptionNode.ServerNode.ProfileNode.DhcpOps.RemoveOptionValue(OptionNode.ServerNode.ServerIp, oldValue);
                        }
                        catch (Exception e)
                        {
                            SnapInUtil.PopUpError("Option Error", "Remove Option Failed" + Environment.NewLine +
                                "Error: " + e.Message);
                            return false;
                        }
                    }
                }

                OptionNode.OptionValues = newValues;
            }
            return true;
        }

        protected override bool OnOK()
        {
            return this.OnApply();
        }

        private void SetData()
        {
            ((OptionControl)this.Control).SetData();
        }
    }
}
