/* 
 * DHCP Web Services MMC 3.0 Snap-In Client
 *
 *  File: DhcpIpAddress.cs
 *  Namespace: Unf.Dhcp.ManagementConsole.DwsOps
 *  
 *
 * Copyright (c) 2008 Jason Rupard 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *     * Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 * 
*/
using System;
using System.Net;
using System.Collections.Generic;
using System.Text;

namespace Unf.Dhcp.ManagementConsole.DwsOps
{
    public partial class DhcpIpAddress
    {
        public DhcpIpAddress() { this.ipField = IPAddress.Any.ToString(); }
        public DhcpIpAddress(UInt32 IpUInt) { this.ipField = DhcpIpAddress.UInt2Str(IpUInt); }
        public DhcpIpAddress(String IpString) 
        {
            IPAddress outIp;
            if (!IPAddress.TryParse(IpString, out outIp))
            {
                this.ipField = IPAddress.Any.ToString();
                throw new FormatException("IpAddress invalid format");
            }
            this.ipField = IpString;
     
        }

        public override String ToString()
        {
            return ipField;
        }

        public UInt32 GetUIntAddress()
        {
            return DhcpIpAddress.Str2UInt(this.ipField);
        }

        public static UInt32 Str2UInt(String IpString)
        {
            IPAddress ip = IPAddress.Parse(IpString);

            byte[] ipBytes = ip.GetAddressBytes();

            UInt32 ipUInt = (UInt32)ipBytes[0] << 24;
            ipUInt += (UInt32)ipBytes[1] << 16;
            ipUInt += (UInt32)ipBytes[2] << 8;
            ipUInt += (UInt32)ipBytes[3];

            return ipUInt;
        }

        public static String UInt2Str(UInt32 IpUInt)
        {
            IPAddress ip = new IPAddress(IpUInt);
            string[] strIp = ip.ToString().Split('.');

            return strIp[3] + "." + strIp[2] + "." + strIp[1] + "." + strIp[0];
        }
    }
}

namespace Unf.Dhcp.ManagementConsole.DwsSec
{
    public partial class DhcpIpAddress
    {
        public DhcpIpAddress() { this.ipField = IPAddress.Any.ToString(); }
        public DhcpIpAddress(String IpString)
        {
            IPAddress outIp;
            if (!IPAddress.TryParse(IpString, out outIp))
            {
                this.ipField = IPAddress.Any.ToString();
                throw new FormatException("IpAddress invalid format");
            }
            this.ipField = IpString;

        }

        public override String ToString()
        {
            return ipField;
        }

        public UInt32 GetUIntAddress()
        {
            return DhcpIpAddress.Str2UInt(this.ipField);
        }

        public static UInt32 Str2UInt(String IpString)
        {
            IPAddress ip = IPAddress.Parse(IpString);

            byte[] ipBytes = ip.GetAddressBytes();

            UInt32 ipUInt = (UInt32)ipBytes[0] << 24;
            ipUInt += (UInt32)ipBytes[1] << 16;
            ipUInt += (UInt32)ipBytes[2] << 8;
            ipUInt += (UInt32)ipBytes[3];

            return ipUInt;
        }

        public static String UInt2Str(UInt32 IpUInt)
        {
            IPAddress ip = new IPAddress(IpUInt);
            string[] strIp = ip.ToString().Split('.');

            return strIp[3] + "." + strIp[2] + "." + strIp[1] + "." + strIp[0];
        }
    }
}
