/* 
 * DHCP Web Services MMC 3.0 Snap-In Client
 *
 *  File: DhcpOptionData.cs
 *  Namespace: Unf.Dhcp.ManagementConsole.DwsOps
 *  
 *
 * Copyright (c) 2008 Jason Rupard 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *     * Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 * 
*/
using System;
using System.Collections.Generic;
using System.Text;

namespace Unf.Dhcp.ManagementConsole.DwsOps
{
    public abstract partial class DhcpOptionData
    {
        public static DhcpOptionData GenOptionData(DhcpOptionDataType type, String[] data)
        {
            switch (type)
            {
                case DhcpOptionDataType.ByteType:
                    return DhcpOptionDataByte.GenOptionData(data);

                case DhcpOptionDataType.WordType:
                    return DhcpOptionDataWord.GenOptionData(data);

                case DhcpOptionDataType.DWordType:
                    return DhcpOptionDataDword.GenOptionData(data);

                case DhcpOptionDataType.DWordDWordType:
                    return DhcpOptionDataDwordDword.GenOptionData(data);

                case DhcpOptionDataType.StringDataType:
                    return DhcpOptionDataString.GenOptionData(data);
   
                case DhcpOptionDataType.IpAddressType:
                    return DhcpOptionDataIp.GenOptionData(data);
    
            }
            return null;
        }
        public abstract override String ToString();
        public abstract String[] GetStrings();
    }

    public partial class DhcpOptionDataByte : DhcpOptionData
    {
        public static DhcpOptionData GenOptionData(string[] data)
        {
            DhcpOptionDataByte od = new DhcpOptionDataByte();
            od.Type = DhcpOptionDataType.ByteType;
            od.Data = new byte[data.Length];
            int i =0;
            foreach (String str in data)
                od.Data[i++] = byte.Parse(str);

            return od;
        }

        public override string ToString()
        {
            return String.Join(", ", this.GetStrings());
        }

        public override String[] GetStrings()
        {
            String[] strs = new String[this.dataField.Length];
            int i = 0;
            foreach(Byte b in this.dataField)
                strs[i++] = b.ToString();
            return strs;
        }
    }

    public partial class DhcpOptionDataIp : DhcpOptionData
    {

        public static DhcpOptionData GenOptionData(string[] data)
        {
            DhcpOptionDataIp od = new DhcpOptionDataIp();
            od.Type = DhcpOptionDataType.IpAddressType;
            od.Data = new DhcpIpAddress[data.Length];
            int i = 0;
            foreach (String str in data)
                od.Data[i++] = new DhcpIpAddress(str);

            return od;
        }

        public override string ToString()
        {
            return String.Join(",", this.GetStrings());
        }

        public override String[] GetStrings()
        {
            String[] strs = new String[this.dataField.Length];
            int i = 0;
            foreach (DhcpIpAddress s in this.dataField)
                strs[i++] = s.ToString();
            return strs;
        }
    }

    public partial class DhcpOptionDataWord : DhcpOptionData
    {

        public static DhcpOptionData GenOptionData(string[] data)
        {
            DhcpOptionDataWord od = new DhcpOptionDataWord();
            od.Type = DhcpOptionDataType.WordType;
            od.Data = new ushort[data.Length];
            int i = 0;
            foreach (String str in data)
                od.Data[i++] = ushort.Parse(str);

            return od;
        }

        public override string ToString()
        {
            return String.Join(",", this.GetStrings());
        }

        public override String[] GetStrings()
        {
            String[] strs = new String[this.dataField.Length];
            int i = 0;
            foreach (ushort s in this.dataField)
                strs[i++] = s.ToString();
            return strs;
        }
    }

    public partial class DhcpOptionDataDword : DhcpOptionData
    {
        public static DhcpOptionData GenOptionData(string[] data)
        {
            DhcpOptionDataDword od = new DhcpOptionDataDword();
            od.Type = DhcpOptionDataType.DWordType;
            od.Data = new uint[data.Length];
            int i = 0;
            foreach (String str in data)
                od.Data[i++] = uint.Parse(str);

            return od;
        }

        public override string ToString()
        {
            return String.Join(",", this.GetStrings());
        }

        public override String[] GetStrings()
        {
            String[] strs = new String[this.dataField.Length];
            int i = 0;
            foreach (uint s in this.dataField)
                strs[i++] = s.ToString();
            return strs;
        }

    }

    public partial class DhcpOptionDataDwordDword : DhcpOptionData
    {
        public static DhcpOptionData GenOptionData(string[] data)
        {
            DhcpOptionDataDwordDword od = new DhcpOptionDataDwordDword();
            od.Type = DhcpOptionDataType.DWordDWordType;
            od.Data = new ulong[data.Length];
            int i = 0;
            foreach (String str in data)
                od.Data[i++] = ulong.Parse(str);

            return od;
        }

        public override string ToString()
        {
            return String.Join(",", this.GetStrings());
        }

        public override String[] GetStrings()
        {
            String[] strs = new String[this.dataField.Length];
            int i = 0;
            foreach (ulong s in this.dataField)
                strs[i++] = s.ToString();
            return strs;
        }

    }

    public partial class DhcpOptionDataString : DhcpOptionData
    {
        public static DhcpOptionData GenOptionData(string[] data)
        {
            DhcpOptionDataString od = new DhcpOptionDataString();
            od.Type = DhcpOptionDataType.StringDataType;
            od.Data = new String[data.Length];
            int i = 0;
            foreach (String str in data)
                od.Data[i++] = str;

            return od;
        }

        public override string ToString()
        {
            return String.Join(",", this.GetStrings());
        }

        public override String[] GetStrings()
        {
            String[] strs = new String[this.dataField.Length];
            int i = 0;
            foreach (String s in this.dataField)
                strs[i++] = s.ToString();
            return strs;
        }
    }
}
