/* 
 * DHCP Web Services MMC 3.0 Snap-In Client
 *
 *  File: LeaseListView.cs
 *  Namespace: Unf.Dhcp.ManagementConsole
 *  
 *
 * Copyright (c) 2008 Jason Rupard 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *     * Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 * 
*/
using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using Microsoft.ManagementConsole;

using Unf.Dhcp.ManagementConsole.DwsOps;

namespace Unf.Dhcp.ManagementConsole
{
    class LeaseListView : MmcListView
    {
        protected override void OnInitialize(AsyncStatus status)
        {
            base.OnInitialize(status);

            // Create a set of columns for use in the list view
            // Define the default column title
            this.Columns[0].Title = "Client IP";
            this.Columns[0].SetWidth(125);


            // Add detail column
            this.Columns.Add(new MmcListViewColumn("Name", 100));
            this.Columns.Add(new MmcListViewColumn("Hardware Address", 100));
            this.Columns.Add(new MmcListViewColumn("Lease Expiration", 125));
            //this.Columns.Add(new MmcListViewColumn("Type", 75));
            this.Columns.Add(new MmcListViewColumn("Description", 175));

            //listen for scope event
            ((LeaseScopeNode)this.ScopeNode).Changed += new LeaseScopeNode.ChangedDelegate(OnScopeNodeChange);

            //allow selected node to be deleted
            this.SelectionData.EnabledStandardVerbs = StandardVerbs.Delete;

            this.Refresh();
        }

        protected override void OnDelete(SyncStatus status)
        {
            String msgText = "'" + this.SelectedNodes[0].DisplayName + "' Lease will be deleted";
             if (SnapInUtil.PopUpConfirm(msgText) == DialogResult.OK)
             {
                 SubnetScopeNode subnetNode = ((LeaseScopeNode)this.ScopeNode).SubnetNode;
                 try
                 {
                     subnetNode.ProfileNode.DhcpOps.DeleteLease(subnetNode.ServerIp, subnetNode.DhcpSubnet.Address,
                         new DhcpIpAddress(this.SelectedNodes[0].DisplayName));
                     this.ResultNodes.Remove((ResultNode)this.SelectedNodes[0]);
                 }
                 catch (Exception e)
                 {
                     SnapInUtil.PopUpError("Lease Error", "Unable to delete DHCP Lease" + Environment.NewLine + "Error: " + e.Message);
                 }
             }
        }

        /// <summary>
        /// Cleanup. 
        /// </summary>
        /// <param name="status"></param>
        protected override void OnShutdown(SyncStatus status)
        {
            //Stop listening for scope event
            ((LeaseScopeNode)this.ScopeNode).Changed -= new LeaseScopeNode.ChangedDelegate(OnScopeNodeChange);
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="status"></param>
        protected override void OnSelectionChanged(SyncStatus status)
        {
            if (this.SelectedNodes.Count == 0)
            {
                this.SelectionData.Clear();
            }
            else
            {
                this.SelectionData.Update(this.SelectedNodes[0], false, null, null);
                this.SelectionData.ActionsPaneItems.Clear();
            }
        }

        // <summary>
        /// Handle any change to the scope node. 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void OnScopeNodeChange(object sender, EventArgs ev)
        {
            this.Refresh();
        }

        private void Refresh()
        {
            this.ResultNodes.Clear();

            SubnetScopeNode subnetNode = ((LeaseScopeNode)this.ScopeNode).SubnetNode;
            try
            {
                DhcpClient[] clients = subnetNode.ProfileNode.DhcpOps.EnumLeases(subnetNode.ServerIp, subnetNode.DhcpSubnet.Address);
                if(clients == null)
                    clients = new DhcpClient[0];

                foreach (DhcpClient client in clients)
                    this.ResultNodes.Add(new LeaseResultNode(client));
            }
            catch (Exception e)
            {
                SnapInUtil.PopUpError("Lease Error", "Unable to query DHCP Leases" + Environment.NewLine + "Error: " + e.Message);
            }
        }
    }
}
