/* 
 * DHCP Web Services MMC 3.0 Snap-In Client
 *
 *  File: OptionListView.cs
 *  Namespace: Unf.Dhcp.ManagementConsole
 *  
 *
 * Copyright (c) 2008 Jason Rupard 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *     * Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 * 
*/
using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.ManagementConsole;

using Unf.Dhcp.ManagementConsole.DwsOps;

namespace Unf.Dhcp.ManagementConsole
{
    class OptionListView : MmcListView
    {
        protected override void OnInitialize(AsyncStatus status)
        {
            base.OnInitialize(status);

            // Create a set of columns for use in the list view
            // Define the default column title
            this.Columns[0].Title = "Name";
            this.Columns[0].SetWidth(150);


            // Add detail column
            this.Columns.Add(new MmcListViewColumn("OptionId", 75));
            this.Columns.Add(new MmcListViewColumn("Class", 75));
            this.Columns.Add(new MmcListViewColumn("Value", 150));
            this.Columns.Add(new MmcListViewColumn("Description", 150));


            //listen for scope event
            ((OptionScopeNode)this.ScopeNode).Changed += new OptionScopeNode.ChangedDelegate(OnScopeNodeChange);

            //allow selected node to be deleted
            
            this.SelectionData.EnabledStandardVerbs = StandardVerbs.Delete;

            this.Refresh();
        }

        /// <summary>
        /// Cleanup. 
        /// </summary>
        /// <param name="status"></param>
        protected override void OnShutdown(SyncStatus status)
        {
            //Stop listening for scope event
            ((OptionScopeNode)this.ScopeNode).Changed -= new OptionScopeNode.ChangedDelegate(OnScopeNodeChange);
        }

        protected void Refresh()
        {
            this.ResultNodes.Clear();

            OptionScopeNode optNode = (OptionScopeNode)this.ScopeNode;

            foreach (DhcpOptionValue value in optNode.OptionValues)
            {

                if (value.OptionId == 81)
                    continue;

                this.ResultNodes.Add(new OptionResultNode(optNode, value));
            }
            
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="status"></param>
        protected override void OnDelete(SyncStatus status)
        {
            DhcpIpAddress server = ((OptionScopeNode)this.ScopeNode).ServerNode.ServerIp;
            DhcpOptionScope optScope = ((OptionScopeNode)this.ScopeNode).OptScope;

            try
            {
                ((OptionScopeNode)this.ScopeNode).ServerNode.ProfileNode.DhcpOps.RemoveOptionValue(server, 
                    ((OptionResultNode)this.SelectedNodes[0]).OptValue);
                this.ResultNodes.Remove((OptionResultNode)this.SelectedNodes[0]);
                ((OptionScopeNode)this.ScopeNode).OptionValues.Remove(((OptionResultNode)this.SelectedNodes[0]).OptValue);
            }
            catch(Exception e)
            {
                SnapInUtil.PopUpError("Option Error", "Unable to delete DHCP Option" + Environment.NewLine + "Error: " + e.Message);
            }
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="status"></param>
        protected override void OnSelectionChanged(SyncStatus status)
        {
            if (this.SelectedNodes.Count == 0)
            {
                this.SelectionData.Clear();
            }
            else
            {
                this.SelectionData.Update(this.SelectedNodes[0], false, null, null);
                this.SelectionData.ActionsPaneItems.Clear();
            }
        }

        /// <summary>
        /// Handle any change to the scope node. 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void OnScopeNodeChange(object sender, EventArgs ev)
        {
            this.Refresh();
        }

        /// <summary>
        /// OnAddPropertyPages is used to get the property pages to show.
        /// </summary>
        /// <param name="propertyPageCollection">property pages</param>
        protected override void OnAddPropertyPages(PropertyPageCollection propertyPageCollection)
        {
            if (this.SelectedNodes.Count == 1)
            {
                // add at least one property page relevant to the selection
                propertyPageCollection.Add(new OptionPropertyPage((OptionScopeNode)this.ScopeNode));
            }
        }
    }
}
