#!/usr/bin/perl
#
# DHCP Web Services Client
# using SOAP::Lite
#
# Search entire DHCP server
#
# Command Line:
#  -i <IP regex pattern>
#  -m <MAC regex pattern>
#  -n <Name regex pattern>
# 
# regex is a .NET regular express format and case insensitive
# http://msdn2.microsoft.com/en-us/library/az24scfc(VS.80).aspx
#
#
# Copyright (c) 2008 Jason Rupard 
# All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
# 
#     * Redistributions of source code must retain the above copyright notice,
#     this list of conditions and the following disclaimer.
# 
#     * Redistributions in binary form must reproduce the above copyright
#     notice, this list of conditions and the following disclaimer in the
#     documentation and/or other materials provided with the distribution.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
#

#use SOAP::Lite +trace => debug;
use SOAP::Lite;
use Getopt::Std;

my $dws = SOAP::Lite
  -> uri('http://www.unf.edu/~jrupard/dws/')
  -> proxy('https://jr1/x/DhcpOperations.asmx')
  -> on_action( sub { join '/', 'http://www.unf.edu/~jrupard/dws', $_[1] } );

my $serverIp = SOAP::Data->name(
	server => \SOAP::Data->value(SOAP::Data->name(Ip => '<server ip>'))
    ); 

getopts('i:m:n:', \ my %opts);

my $terms = 
 SOAP::Data->name(terms => \SOAP::Data->value(
   SOAP::Data->name(IpRegEx => $opts{i} || ''),
   SOAP::Data->name(MacRegEx => $opts{m}|| ''),
   SOAP::Data->name(NameRegEx => $opts{n} || '')
 ));

my $res = $dws->ServerFindAllClients($serverIp, $terms);
die $res->faultstring."\n" if  ($res->fault);


my @clients;
if($res->result->{DhcpClient} =~ /ARRAY/) {
 @clients = @{$res->result->{DhcpClient}};
}
else {
 @clients = ($res->result->{DhcpClient});
}


printf "\n%-24s %-12s %-12s %-10s\n", "IpAddress", "Mac", "Name", "LeaseExpires";
printf "%-24s %-12s %-12s %-10s\n", "-"x24, "-"x12, "-"x12, "-"x10;
foreach(@clients)
{
 printf "%-24s %-12s %-12s %-10s\n", $_->{IpAddress}->{Ip}, $_->{MacAddress}->{Mac}, $_->{Name}, $_->{LeaseExpires};
}

printf "%-24s %-12s %-12s %-10s\n", "-"x24, "-"x12, "-"x12, "-"x10;
printf "%-24s %-12s %-12s %-10s\n", "IpAddress", "Mac", "Name", "LeaseExpires";
print "\n";

sub SOAP::Transport::HTTP::Client::get_basic_credentials { 
  return "<user>" => "<pass>";
}
