/* 
 * DHCP Server Management Objects
 *
 *  File: DhcpAzAccount.cs
 *  Namespace: Unf.Dhcp.Smo.WebServices
 *  
 *
 * Copyright (c) 2008 Jason Rupard 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *     * Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 * 
*/
using System;

namespace Unf.Dhcp.Smo.WebServices
{
    /// <summary>
    /// Defines an authorizated account in AzMan
    /// </summary>
    public class DhcpAzAccount
    {
        /// <summary>
        /// Account name: user@domain, group@domain, domain\user, domain\group
        /// </summary>
        public String AccountName;
        /// <summary>
        /// Dhcp authorization role account belongs to
        /// </summary>
        public DhcpAzRole Role;

        /// <summary>
        /// Dummy constructor
        /// </summary>
        public DhcpAzAccount(){}

        /// <summary>
        /// Creates new object based on account name and role type
        /// </summary>
        /// <param name="accountName">New account name</param>
        /// <param name="role">New account role</param>
        public DhcpAzAccount(String accountName, DhcpAzRole role)
        {
            this.AccountName = accountName;
            this.Role = role;
        }
    }

    /// <summary>
    /// Defines a global authorizated account in AzMan
    /// </summary>
    public class DhcpAzGlobalAccount
    {
        /// <summary>
        /// Account name: user@domain, group@domain, domain\user, domain\group
        /// </summary>
        public String AccountName;
        /// <summary>
        /// Dhcp global authorization role account belongs to
        /// </summary>
        public DhcpAzGlobalRole GlobalRole;

        /// <summary>
        /// Dummy constructor
        /// </summary>
        public DhcpAzGlobalAccount(){}

        /// <summary>
        /// Creates new object based on account name and role type
        /// </summary>
        /// <param name="accountName">New account name</param>
        /// <param name="role">New account role</param>
        public DhcpAzGlobalAccount(String accountName, DhcpAzGlobalRole role)
        {
            this.AccountName = accountName;
            this.GlobalRole = role;
        }
    }

    /// <summary>
    /// DHCP global authorization roles
    /// </summary>
    public enum DhcpAzGlobalRole
    {
        /// <summary>
        /// Global read only access
        /// </summary>
        GlobalAuditor = 0,
        /// <summary>
        /// Global administrator access
        /// </summary>
        GlobalAdministrator = 1
    }

    /// <summary>
    /// Scope specific DHCP authorization roles
    /// </summary>
    public enum DhcpAzRole
    {
        /// <summary>
        /// Scope specific read only role
        /// </summary>
        Auditor = 1,
        /// <summary>
        /// Scope specific read/update only role
        /// </summary>
        Manager = 2,
        /// <summary>
        /// Scope specific read/update/create/delete role
        /// </summary>
        Owner = 3
    }
}
