/* 
 * DHCP Server Management Objects
 *
 *  File: DhcpException.cs
 *  Namespace: Unf.Dhcp.Smo
 *  
 *
 * Copyright (c) 2008 Jason Rupard 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *     * Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 * 
 *     * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 * 
*/
using System;
using System.Collections.Generic;
using System.Text;
using System.ComponentModel;

using Unf.Dhcp.Smo.Interop;

namespace Unf.Dhcp.Smo
{
    /// <summary>
    /// Dhcp specific exception object
    /// </summary>
    public class DhcpException : ApplicationException
    {
        private uint DhcpErrCode;
        private bool isDhcpErr = true;

        /// <summary>
        /// Create a new DhcpException based on error code
        /// </summary>
        /// <param name="code">A DHCPSAPI or WIN32 error code</param>
        public DhcpException(uint code)
        {
            DhcpErrCode = code;
            if(!Enum.IsDefined(typeof(DhcpsapiErrorType), code))
            { isDhcpErr = false; }
        }

        /// <summary>
        /// Message string based on error code from constructor
        /// </summary>
        public override string Message
        {
            get
            {
                if (isDhcpErr)
                {
                    return DhcpsapiError.GetDesc((DhcpsapiErrorType)DhcpErrCode);
                }
                else
                {
                    Win32Exception ex = new Win32Exception((int)DhcpErrCode);
                    return ex.Message;
                }
                
            }
        }
    }
}
